==> jc-1.4.0.tar.gz: java/util/TimerTask.h <==
// public abstract class java.util.TimerTask

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9ededa118c413cea java_util_TimerTask

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_TimerTask_H_
#define _JC_java_util_TimerTask_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_TimerTask$sub_refs	_jc_java_util_TimerTask$sub_refs;
typedef struct _jc_java_util_TimerTask$sub_nonrefs	_jc_java_util_TimerTask$sub_nonrefs;
typedef struct _jc_java_util_TimerTask$refs	_jc_java_util_TimerTask$refs;
typedef struct _jc_java_util_TimerTask$nonrefs	_jc_java_util_TimerTask$nonrefs;
typedef struct _jc_java_util_TimerTask$object	_jc_java_util_TimerTask$object;

typedef const struct _jc_java_util_TimerTask$vmethods	_jc_java_util_TimerTask$vmethods;
typedef const struct _jc_java_util_TimerTask$vtable	_jc_java_util_TimerTask$vtable;
typedef const struct _jc_java_util_TimerTask$vtype	_jc_java_util_TimerTask$vtype;

// Constructors
extern void _jc_java_util_TimerTask$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_TimerTask$object *);

// Virtual methods
extern jboolean _jc_java_util_TimerTask$method$cancel$79063b7c94fab1b2(_jc_env *, struct _jc_java_util_TimerTask$object *);
extern void _jc_java_util_TimerTask$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_util_TimerTask$object *);
extern jlong _jc_java_util_TimerTask$method$scheduledExecutionTime$0469dfd3fa121b5d(_jc_env *, struct _jc_java_util_TimerTask$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_TimerTask$method_info$cancel$79063b7c94fab1b2;
extern _jc_method _jc_java_util_TimerTask$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_java_util_TimerTask$method_info$scheduledExecutionTime$0469dfd3fa121b5d;

// Virtual methods structure
struct _jc_java_util_TimerTask$vmethods {
	jboolean	(*cancel$79063b7c94fab1b2)(_jc_env *, struct _jc_java_util_TimerTask$object *);
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_util_TimerTask$object *);
	jlong	(*scheduledExecutionTime$0469dfd3fa121b5d)(_jc_env *, struct _jc_java_util_TimerTask$object *);
};

// Vtable
struct _jc_java_util_TimerTask$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_TimerTask$vmethods	java_util_TimerTask;
};

// Vtype
struct _jc_java_util_TimerTask$vtype {
	_jc_type			type;
	_jc_java_util_TimerTask$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_TimerTask$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_TimerTask$refs {
    _jc_java_util_TimerTask$sub_refs	java_util_TimerTask;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_TimerTask$sub_nonrefs {
	jlong	scheduled;
	jlong	lastExecutionTime;
	jlong	period;
	jboolean	fixed;
};

// Non-reference instance fields (object)
struct _jc_java_util_TimerTask$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_TimerTask$sub_nonrefs	java_util_TimerTask;
};

// Object instance structure
struct _jc_java_util_TimerTask$object {
	_jc_java_util_TimerTask$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_TimerTask$vtype	*vtype;
	_jc_java_util_TimerTask$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_TimerTask$vtype _jc_java_util_TimerTask$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_TimerTask, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_TimerTask$class_object;

#endif	/* _JC_java_util_TimerTask_H_ */

==> jc-1.4.6.tar.gz: java/util/TimerTask.h <==
// public abstract class java.util.TimerTask

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9ededa118c413cea java_util_TimerTask

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_TimerTask_H_
#define _JC_java_util_TimerTask_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_TimerTask$sub_refs	_jc_java_util_TimerTask$sub_refs;
typedef struct _jc_java_util_TimerTask$sub_nonrefs	_jc_java_util_TimerTask$sub_nonrefs;
typedef struct _jc_java_util_TimerTask$refs	_jc_java_util_TimerTask$refs;
typedef struct _jc_java_util_TimerTask$nonrefs	_jc_java_util_TimerTask$nonrefs;
typedef struct _jc_java_util_TimerTask$object	_jc_java_util_TimerTask$object;

typedef const struct _jc_java_util_TimerTask$vmethods	_jc_java_util_TimerTask$vmethods;
typedef const struct _jc_java_util_TimerTask$vtable	_jc_java_util_TimerTask$vtable;
typedef const struct _jc_java_util_TimerTask$vtype	_jc_java_util_TimerTask$vtype;

// Constructors
extern void _jc_java_util_TimerTask$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_TimerTask$method$cancel$79063b7c94fab1b2(_jc_env *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_TimerTask$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_util_TimerTask$method$scheduledExecutionTime$0469dfd3fa121b5d(_jc_env *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_TimerTask$method_info$cancel$79063b7c94fab1b2;
extern _jc_method _jc_java_util_TimerTask$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_java_util_TimerTask$method_info$scheduledExecutionTime$0469dfd3fa121b5d;

// Virtual methods structure
struct _jc_java_util_TimerTask$vmethods {
	jboolean	(*cancel$79063b7c94fab1b2)(_jc_env *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
	jlong	(*scheduledExecutionTime$0469dfd3fa121b5d)(_jc_env *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_TimerTask$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_TimerTask$vmethods	java_util_TimerTask;
};

// Vtype
struct _jc_java_util_TimerTask$vtype {
	_jc_type			type;
	_jc_java_util_TimerTask$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_TimerTask$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_TimerTask$refs {
    _jc_java_util_TimerTask$sub_refs	java_util_TimerTask;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_TimerTask$sub_nonrefs {
	jlong	scheduled;
	jlong	lastExecutionTime;
	jlong	period;
	jboolean	fixed;
};

// Non-reference instance fields (object)
struct _jc_java_util_TimerTask$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_TimerTask$sub_nonrefs	java_util_TimerTask;
};

// Object instance structure
struct _jc_java_util_TimerTask$object {
	_jc_java_util_TimerTask$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_TimerTask$vtype	*vtype;
	_jc_java_util_TimerTask$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_TimerTask$vtype _jc_java_util_TimerTask$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_TimerTask, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_TimerTask$class_object;

#endif	/* _JC_java_util_TimerTask_H_ */
